@@ -23,6 +23,7 @@ use strict;
 use warnings;
 use autodie;
 
+use List::MoreUtils qw(any);
 use Text::Levenshtein qw(distance);
 
 use Lintian::Data;
@@ -433,7 +434,9 @@ sub run {
 
     while (my ($dep, $command) = each %missingbdeps) {
         next if $dep eq 'debhelper'; #handled above
-        next if $dep eq 'autotools-dev' and $level >= 10;
+        next
+          if $level >= 10
+          and any { $_ eq $dep } qw(autotools-dev dh-strip-nondeterminism);
         tag 'missing-build-dependency-for-dh_-command', "$command => $dep"
           unless ($bdepends_noarch->implies($dep));
     }
