@@ -164,7 +164,7 @@ General options:
     -q, --quiet               suppress all informational messages
     -v, --verbose             verbose messages
     -V, --version             display Lintian version and exit
-Behaviour options:
+Behavior options:
     --color never/always/auto disable, enable, or enable color for TTY
     --default-display-level   reset the display level to the default
     --display-source X        restrict displayed tags by source
@@ -635,6 +635,7 @@ sub main {
 
     $PROFILE = load_profile_and_configure_tags();
 
+    $SIG{'TERM'} = \&interrupted;
     $SIG{'INT'} = \&interrupted;
     $SIG{'QUIT'} = \&interrupted;
 
@@ -1205,6 +1206,7 @@ sub parse_config_file {
         'quiet'                => \&cfg_verbosity,
         'override'             => \&cfg_override,
         'show-overrides'       => \$opt{'show-overrides'},
+        'suppress-tags'        => \&record_suppress_tags,
         'verbose'              => \&cfg_verbosity,
     );
 
